==> kdepim-addons-16.11.90.tar.xz: kdepim-addons-16.11.90/kmail/editorsendcheckplugins/automaticaddcontacts/automaticaddcontactsconfiguredialog.h <==
/*
   Copyright (C) 2016 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef AUTOMATICADDCONTACTSCONFIGUREDIALOG_H
#define AUTOMATICADDCONTACTSCONFIGUREDIALOG_H

#include <PimCommon/ConfigurePluginDialog>

class AutomaticAddContactsConfigureWidget;
class AutomaticAddContactsConfigureDialog : public PimCommon::ConfigurePluginDialog
{
    Q_OBJECT
public:
    explicit AutomaticAddContactsConfigureDialog(QWidget *parent = Q_NULLPTR);
    ~AutomaticAddContactsConfigureDialog();

protected:
    QWidget *createLayout() Q_DECL_OVERRIDE;
    void save() Q_DECL_OVERRIDE;
    void load() Q_DECL_OVERRIDE;
    void reset() Q_DECL_OVERRIDE;
    void help() Q_DECL_OVERRIDE;

private:
    AutomaticAddContactsConfigureWidget *mConfigureWidget;
};

#endif // AUTOMATICADDCONTACTSCONFIGUREDIALOG_H

==> kdepim-addons-17.03.80.tar.xz: kdepim-addons-17.03.80/kmail/editorsendcheckplugins/automaticaddcontacts/automaticaddcontactsconfiguredialog.h <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef AUTOMATICADDCONTACTSCONFIGUREDIALOG_H
#define AUTOMATICADDCONTACTSCONFIGUREDIALOG_H

#include <PimCommon/ConfigurePluginDialog>

class AutomaticAddContactsConfigureWidget;
class AutomaticAddContactsConfigureDialog : public PimCommon::ConfigurePluginDialog
{
    Q_OBJECT
public:
    explicit AutomaticAddContactsConfigureDialog(QWidget *parent = nullptr);
    ~AutomaticAddContactsConfigureDialog();

protected:
    QWidget *createLayout() Q_DECL_OVERRIDE;
    void save() Q_DECL_OVERRIDE;
    void load() Q_DECL_OVERRIDE;
    void reset() Q_DECL_OVERRIDE;
    void help() Q_DECL_OVERRIDE;

private:
    AutomaticAddContactsConfigureWidget *mConfigureWidget;
};

#endif // AUTOMATICADDCONTACTSCONFIGUREDIALOG_H
